@@ -124,6 +124,7 @@ typedef guint PkMediaTypeEnum;
 #define PK_ERROR_ENUM_PACKAGE_FAILED_TO_INSTALL		(PK_ERROR_ENUM_PACKAGE_FAILED_TO_BUILD + 1)
 #define PK_ERROR_ENUM_PACKAGE_FAILED_TO_REMOVE		(PK_ERROR_ENUM_PACKAGE_FAILED_TO_INSTALL + 1)
 #define PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED		(PK_MESSAGE_ENUM_PACKAGE_ALREADY_INSTALLED + 1)
+#define PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED	(PK_MESSAGE_ENUM_AUTOREMOVE_IGNORED + 1)
 #define PK_PROVIDES_ENUM_POSTSCRIPT_DRIVER		(PK_PROVIDES_ENUM_HARDWARE_DRIVER + 1)
 #define PK_ROLE_ENUM_SIMULATE_INSTALL_FILES		(PK_ROLE_ENUM_GET_OLD_TRANSACTIONS + 1)
 #define PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES		(PK_ROLE_ENUM_SIMULATE_INSTALL_FILES + 1)
@@ -131,7 +132,10 @@ typedef guint PkMediaTypeEnum;
 #define PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES		(PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES + 1)
 #undef PK_ROLE_ENUM_UNKNOWN
 #define PK_ROLE_ENUM_UNKNOWN				(PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES + 1)
+#undef PK_INFO_ENUM_UNKNOWN
 #define PK_INFO_ENUM_REINSTALLING			(PK_INFO_ENUM_FINISHED + 1)
+#define PK_INFO_ENUM_DOWNGRADING			(PK_INFO_ENUM_REINSTALLING + 1)
+#define PK_INFO_ENUM_UNKNOWN				(PK_INFO_ENUM_DOWNGRADING + 1)
 #endif
 
 void		 gpk_enum_test				(gpointer	 data);
