@@ -25,7 +25,6 @@
 #include <glib/gi18n.h>
 #include <locale.h>
 
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <math.h>
@@ -33,12 +32,12 @@
 #include <dbus/dbus-glib.h>
 #include <gconf/gconf-client.h>
 #include <packagekit-glib/packagekit.h>
+#include <unique/unique.h>
 
 #include <gpk-common.h>
 #include <gpk-gnome.h>
 
 #include "egg-debug.h"
-#include "egg-unique.h"
 #include "gpk-enum.h"
 
 /* TRANSLATORS: check once an hour */
@@ -57,7 +56,12 @@
 /* TRANSLATORS: don't update anything */
 #define PK_UPDATE_NONE_TEXT		_("Nothing")
 
-static GladeXML *glade_xml = NULL;
+#define GPK_PREFS_VALUE_NEVER		(0)
+#define GPK_PREFS_VALUE_HOURLY		(60*60)
+#define GPK_PREFS_VALUE_DAILY		(60*60*24)
+#define GPK_PREFS_VALUE_WEEKLY		(60*60*24*7)
+
+static GtkBuilder *builder = NULL;
 
 /**
  * pk_button_help_cb:
@@ -89,70 +93,66 @@ pk_button_checkbutton_clicked_cb (GtkWidget *widget, gpointer data)
 }
 
 /**
- * pk_prefs_update_freq_combo_changed:
+ * gpk_prefs_update_freq_combo_changed:
  **/
 static void
-pk_prefs_update_freq_combo_changed (GtkWidget *widget, gpointer data)
+gpk_prefs_update_freq_combo_changed (GtkWidget *widget, gpointer data)
 {
 	gchar *value;
-	const gchar *action;
-	GpkFreqEnum freq = GPK_FREQ_ENUM_UNKNOWN;
+	guint freq = 0;
 	GConfClient *client;
 
 	client = gconf_client_get_default ();
 	value = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
 	if (strcmp (value, PK_FREQ_HOURLY_TEXT) == 0)
-		freq = GPK_FREQ_ENUM_HOURLY;
+		freq = GPK_PREFS_VALUE_HOURLY;
 	else if (strcmp (value, PK_FREQ_DAILY_TEXT) == 0)
-		freq = GPK_FREQ_ENUM_DAILY;
+		freq = GPK_PREFS_VALUE_DAILY;
 	else if (strcmp (value, PK_FREQ_WEEKLY_TEXT) == 0)
-		freq = GPK_FREQ_ENUM_WEEKLY;
+		freq = GPK_PREFS_VALUE_WEEKLY;
 	else if (strcmp (value, PK_FREQ_NEVER_TEXT) == 0)
-		freq = GPK_FREQ_ENUM_NEVER;
+		freq = GPK_PREFS_VALUE_NEVER;
 	else
 		g_assert (FALSE);
 
-	action = gpk_freq_enum_to_text (freq);
-	egg_debug ("Changing %s to %s", GPK_CONF_FREQUENCY_GET_UPDATES, action);
-	gconf_client_set_string (client, GPK_CONF_FREQUENCY_GET_UPDATES, action, NULL);
+	egg_debug ("Changing %s to %i", GPK_CONF_FREQUENCY_GET_UPDATES, freq);
+	gconf_client_set_int (client, GPK_CONF_FREQUENCY_GET_UPDATES, freq, NULL);
 	g_free (value);
 	g_object_unref (client);
 }
 
 /**
- * pk_prefs_upgrade_freq_combo_changed:
+ * gpk_prefs_upgrade_freq_combo_changed:
  **/
 static void
-pk_prefs_upgrade_freq_combo_changed (GtkWidget *widget, gpointer data)
+gpk_prefs_upgrade_freq_combo_changed (GtkWidget *widget, gpointer data)
 {
 	gchar *value;
-	const gchar *action;
-	GpkFreqEnum freq = GPK_FREQ_ENUM_UNKNOWN;
+	guint freq = 0;
 	GConfClient *client;
 
 	client = gconf_client_get_default ();
 	value = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
 	if (strcmp (value, PK_FREQ_DAILY_TEXT) == 0)
-		freq = GPK_FREQ_ENUM_DAILY;
+		freq = GPK_PREFS_VALUE_DAILY;
 	else if (strcmp (value, PK_FREQ_WEEKLY_TEXT) == 0)
-		freq = GPK_FREQ_ENUM_WEEKLY;
+		freq = GPK_PREFS_VALUE_WEEKLY;
 	else if (strcmp (value, PK_FREQ_NEVER_TEXT) == 0)
-		freq = GPK_FREQ_ENUM_NEVER;
+		freq = GPK_PREFS_VALUE_NEVER;
 	else
 		g_assert (FALSE);
 
-	action = gpk_freq_enum_to_text (freq);
-	egg_debug ("Changing %s to %s", GPK_CONF_FREQUENCY_GET_UPGRADES, action);
-	gconf_client_set_string (client, GPK_CONF_FREQUENCY_GET_UPGRADES, action, NULL);
+	egg_debug ("Changing %s to %i", GPK_CONF_FREQUENCY_GET_UPGRADES, freq);
+	gconf_client_set_int (client, GPK_CONF_FREQUENCY_GET_UPGRADES, freq, NULL);
 	g_free (value);
 	g_object_unref (client);
 }
 
 /**
- * pk_prefs_update_combo_changed:
+ * gpk_prefs_update_combo_changed:
  **/
 static void
-pk_prefs_update_combo_changed (GtkWidget *widget, gpointer data)
+gpk_prefs_update_combo_changed (GtkWidget *widget, gpointer data)
 {
 	gchar *value;
 	const gchar *action;
@@ -166,16 +166,13 @@ pk_prefs_update_combo_changed (GtkWidget *widget, gpointer data)
 		egg_warning ("value NULL");
 		return;
 	}
-	notify_widget = glade_xml_get_widget (glade_xml, "checkbutton_notify_updates");
+	notify_widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_notify_updates"));
 	if (strcmp (value, PK_UPDATE_ALL_TEXT) == 0) {
 		update = GPK_UPDATE_ENUM_ALL;
-		gtk_widget_set_sensitive (notify_widget, FALSE);
 	} else if (strcmp (value, PK_UPDATE_SECURITY_TEXT) == 0) {
 		update = GPK_UPDATE_ENUM_SECURITY;
-		gtk_widget_set_sensitive (notify_widget, TRUE);
 	} else if (strcmp (value, PK_UPDATE_NONE_TEXT) == 0) {
 		update = GPK_UPDATE_ENUM_NONE;
-		gtk_widget_set_sensitive (notify_widget, TRUE);
 	} else {
 		g_assert (FALSE);
 	}
@@ -188,89 +185,113 @@ pk_prefs_update_combo_changed (GtkWidget *widget, gpointer data)
 }
 
 /**
- * pk_prefs_update_freq_combo_setup:
+ * gpk_prefs_set_combo_model_simple_text:
  **/
 static void
-pk_prefs_update_freq_combo_setup (void)
+gpk_prefs_update_freq_combo_simple_text (GtkWidget *combo_box)
 {
-	gchar *value;
+	GtkCellRenderer *cell;
+	GtkListStore *store;
+
+	store = gtk_list_store_new (1, G_TYPE_STRING);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (combo_box), GTK_TREE_MODEL (store));
+	g_object_unref (store);
+
+	cell = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), cell, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), cell,
+					"text", 0,
+					NULL);
+}
+
+/**
+ * gpk_prefs_update_freq_combo_setup:
+ **/
+static void
+gpk_prefs_update_freq_combo_setup (void)
+{
+	guint value;
 	gboolean is_writable;
 	GtkWidget *widget;
-	GpkFreqEnum freq;
 	GConfClient *client;
 
 	client = gconf_client_get_default ();
-	widget = glade_xml_get_widget (glade_xml, "combobox_check");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_check"));
 	is_writable = gconf_client_key_is_writable (client, GPK_CONF_FREQUENCY_GET_UPDATES, NULL);
-	value = gconf_client_get_string (client, GPK_CONF_FREQUENCY_GET_UPDATES, NULL);
-	if (value == NULL) {
-		egg_warning ("invalid schema, please re-install");
-		return;
-	}
-	egg_debug ("value from gconf %s", value);
-	freq = gpk_freq_enum_from_text (value);
-	g_free (value);
+	value = gconf_client_get_int (client, GPK_CONF_FREQUENCY_GET_UPDATES, NULL);
+	egg_debug ("value from gconf %i", value);
 	g_object_unref (client);
 
 	/* do we have permission to write? */
 	gtk_widget_set_sensitive (widget, is_writable);
 
+	/* set a simple text model */
+	gpk_prefs_update_freq_combo_simple_text (widget);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), PK_FREQ_HOURLY_TEXT);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), PK_FREQ_DAILY_TEXT);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), PK_FREQ_WEEKLY_TEXT);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), PK_FREQ_NEVER_TEXT);
-	/* we can do this as it's the same order */
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), freq);
+
+	/* select the correct entry */
+	if (value == GPK_PREFS_VALUE_HOURLY)
+		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
+	else if (value == GPK_PREFS_VALUE_DAILY)
+		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 1);
+	else if (value == GPK_PREFS_VALUE_WEEKLY)
+		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 2);
+	else if (value == GPK_PREFS_VALUE_NEVER)
+		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 3);
 
 	/* only do this after else we redraw the window */
 	g_signal_connect (G_OBJECT (widget), "changed",
-			  G_CALLBACK (pk_prefs_update_freq_combo_changed), NULL);
+			  G_CALLBACK (gpk_prefs_update_freq_combo_changed), NULL);
 }
 
 /**
- * pk_prefs_upgrade_freq_combo_setup:
+ * gpk_prefs_upgrade_freq_combo_setup:
  **/
 static void
-pk_prefs_upgrade_freq_combo_setup (void)
+gpk_prefs_upgrade_freq_combo_setup (void)
 {
-	gchar *value;
+	guint value;
 	gboolean is_writable;
 	GtkWidget *widget;
-	GpkFreqEnum freq;
 	GConfClient *client;
 
 	client = gconf_client_get_default ();
-	widget = glade_xml_get_widget (glade_xml, "combobox_upgrade");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_upgrade"));
 	is_writable = gconf_client_key_is_writable (client, GPK_CONF_FREQUENCY_GET_UPGRADES, NULL);
-	value = gconf_client_get_string (client, GPK_CONF_FREQUENCY_GET_UPGRADES, NULL);
-	if (value == NULL) {
-		egg_warning ("invalid schema, please re-install");
-		return;
-	}
-	egg_debug ("value from gconf %s", value);
-	freq = gpk_freq_enum_from_text (value);
-	g_free (value);
+	value = gconf_client_get_int (client, GPK_CONF_FREQUENCY_GET_UPGRADES, NULL);
+	egg_debug ("value from gconf %i", value);
 	g_object_unref (client);
 
 	/* do we have permission to write? */
 	gtk_widget_set_sensitive (widget, is_writable);
 
+	/* set a simple text model */
+	gpk_prefs_update_freq_combo_simple_text (widget);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), PK_FREQ_DAILY_TEXT);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), PK_FREQ_WEEKLY_TEXT);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), PK_FREQ_NEVER_TEXT);
-	/* don't do daily */
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), freq - 1);
+
+	/* select the correct entry */
+	if (value == GPK_PREFS_VALUE_DAILY)
+		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
+	else if (value == GPK_PREFS_VALUE_WEEKLY)
+		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 1);
+	else if (value == GPK_PREFS_VALUE_NEVER)
+		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 2);
 
 	/* only do this after else we redraw the window */
 	g_signal_connect (G_OBJECT (widget), "changed",
-			  G_CALLBACK (pk_prefs_upgrade_freq_combo_changed), NULL);
+			  G_CALLBACK (gpk_prefs_upgrade_freq_combo_changed), NULL);
 }
 
 /**
- * pk_prefs_auto_update_combo_setup:
+ * gpk_prefs_auto_update_combo_setup:
  **/
 static void
-pk_prefs_auto_update_combo_setup (void)
+gpk_prefs_auto_update_combo_setup (void)
 {
 	gchar *value;
 	gboolean is_writable;
@@ -279,7 +300,7 @@ pk_prefs_auto_update_combo_setup (void)
 	GConfClient *client;
 
 	client = gconf_client_get_default ();
-	widget = glade_xml_get_widget (glade_xml, "combobox_install");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_install"));
 	is_writable = gconf_client_key_is_writable (client, GPK_CONF_AUTO_UPDATE, NULL);
 	value = gconf_client_get_string (client, GPK_CONF_AUTO_UPDATE, NULL);
 	if (value == NULL) {
@@ -294,6 +315,8 @@ pk_prefs_auto_update_combo_setup (void)
 	/* do we have permission to write? */
 	gtk_widget_set_sensitive (widget, is_writable);
 
+	/* set a simple text model */
+	gpk_prefs_update_freq_combo_simple_text (widget);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), PK_UPDATE_ALL_TEXT);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), PK_UPDATE_SECURITY_TEXT);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), PK_UPDATE_NONE_TEXT);
@@ -302,14 +325,14 @@ pk_prefs_auto_update_combo_setup (void)
 
 	/* only do this after else we redraw the window */
 	g_signal_connect (G_OBJECT (widget), "changed",
-			  G_CALLBACK (pk_prefs_update_combo_changed), NULL);
+			  G_CALLBACK (gpk_prefs_update_combo_changed), NULL);
 }
 
 /**
- * pk_prefs_notify_checkbutton_setup:
+ * gpk_prefs_notify_checkbutton_setup:
  **/
 static void
-pk_prefs_notify_checkbutton_setup (GtkWidget *widget, const gchar *gconf_key)
+gpk_prefs_notify_checkbutton_setup (GtkWidget *widget, const gchar *gconf_key)
 {
 	GConfClient *client;
 	gboolean value;
@@ -325,14 +348,16 @@ pk_prefs_notify_checkbutton_setup (GtkWidget *widget, const gchar *gconf_key)
 }
 
 /**
- * gpk_prefs_activated_cb
+ * gpk_prefs_message_received_cb
  **/
 static void
-gpk_prefs_activated_cb (EggUnique *egg_unique, gpointer data)
+gpk_prefs_message_received_cb (UniqueApp *app, UniqueCommand command, UniqueMessageData *message_data, guint time_ms, gpointer data)
 {
-	GtkWidget *widget;
-	widget = glade_xml_get_widget (glade_xml, "dialog_prefs");
-	gtk_window_present (GTK_WINDOW (widget));
+	GtkWindow *window;
+	if (command == UNIQUE_ACTIVATE) {
+		window = GTK_WINDOW (gtk_builder_get_object (builder, "dialog_prefs"));
+		gtk_window_present (window);
+	}
 }
 
 /**
@@ -344,7 +369,7 @@ gpk_prefs_network_status_changed_cb (PkControl *control, PkNetworkEnum state, gp
 	GtkWidget *widget;
 
 	/* only show label on mobile broadband */
-	widget = glade_xml_get_widget (glade_xml, "hbox_mobile_broadband");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "hbox_mobile_broadband"));
 	if (state == PK_NETWORK_ENUM_MOBILE)
 		gtk_widget_show (widget);
 	else
@@ -364,15 +389,20 @@ main (int argc, char *argv[])
 	GtkWidget *widget;
 	PkBitfield roles;
 	PkControl *control;
-	EggUnique *egg_unique;
+	UniqueApp *unique_app;
 	PkNetworkEnum state;
-	gboolean ret;
+	guint retval;
+	guint xid = 0;
+	GError *error = NULL;
 
 	const GOptionEntry options[] = {
 		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
 		  _("Show extra debugging information"), NULL },
 		{ "version", '\0', 0, G_OPTION_ARG_NONE, &program_version,
 		  _("Show the program version and exit"), NULL },
+		{ "parent-window", 'p', 0, G_OPTION_ARG_INT, &xid,
+		  /* TRANSLATORS: we can make this modal (stay on top of) another window */
+		  _("Set the parent window to make this modal"), NULL },
 		{ NULL}
 	};
 
@@ -403,12 +433,14 @@ main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 
 	/* are we already activated? */
-	egg_unique = egg_unique_new ();
-	ret = egg_unique_assign (egg_unique, "org.freedesktop.PackageKit.Prefs");
-	if (!ret)
+	unique_app = unique_app_new ("org.freedesktop.PackageKit.Prefs", NULL);
+	if (unique_app_is_running (unique_app)) {
+		egg_debug ("You have another instance running. This program will now close");
+		unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
 		goto unique_out;
-	g_signal_connect (egg_unique, "activated",
-			  G_CALLBACK (gpk_prefs_activated_cb), NULL);
+	}
+	g_signal_connect (unique_app, "message-received",
+			  G_CALLBACK (gpk_prefs_message_received_cb), NULL);
 
 	/* get actions */
 	control = pk_control_new ();
@@ -417,8 +449,16 @@ main (int argc, char *argv[])
 	roles = pk_control_get_actions (control, NULL);
 	state = pk_control_get_network_state (control, NULL);
 
-	glade_xml = glade_xml_new (GPK_DATA "/gpk-prefs.glade", NULL, NULL);
-	main_window = glade_xml_get_widget (glade_xml, "dialog_prefs");
+	/* get UI */
+	builder = gtk_builder_new ();
+	retval = gtk_builder_add_from_file (builder, GPK_DATA "/gpk-prefs.ui", &error);
+	if (error != NULL) {
+		egg_warning ("failed to load ui: %s", error->message);
+		g_error_free (error);
+		goto out_build;
+	}
+
+	main_window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_prefs"));
 
 	/* Hide window first so that the dialogue resizes itself without redrawing */
 	gtk_widget_hide (main_window);
@@ -427,49 +467,50 @@ main (int argc, char *argv[])
 	/* Get the main window quit */
 	g_signal_connect_swapped (main_window, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
 
-	widget = glade_xml_get_widget (glade_xml, "checkbutton_notify_updates");
-	pk_prefs_notify_checkbutton_setup (widget, GPK_CONF_NOTIFY_AVAILABLE);
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_mobile_broadband"));
+	gpk_prefs_notify_checkbutton_setup (widget, GPK_CONF_CONNECTION_USE_MOBILE);
 
-	widget = glade_xml_get_widget (glade_xml, "checkbutton_notify_completed");
-	pk_prefs_notify_checkbutton_setup (widget, GPK_CONF_NOTIFY_COMPLETED);
-
-	widget = glade_xml_get_widget (glade_xml, "checkbutton_mobile_broadband");
-	pk_prefs_notify_checkbutton_setup (widget, GPK_CONF_CONNECTION_USE_MOBILE);
-
-	widget = glade_xml_get_widget (glade_xml, "button_close");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_close"));
 	g_signal_connect_swapped (widget, "clicked", G_CALLBACK (gtk_main_quit), NULL);
-	widget = glade_xml_get_widget (glade_xml, "button_help");
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_help"));
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (pk_button_help_cb), NULL);
 
 	/* only show label on mobile broadband */
 	if (state == PK_NETWORK_ENUM_MOBILE) {
-		widget = glade_xml_get_widget (glade_xml, "hbox_mobile_broadband");
+		widget = GTK_WIDGET (gtk_builder_get_object (builder, "hbox_mobile_broadband"));
 		gtk_widget_show (widget);
 	}
 
 	/* update the combo boxes */
-	pk_prefs_update_freq_combo_setup ();
-	pk_prefs_upgrade_freq_combo_setup ();
-	pk_prefs_auto_update_combo_setup ();
+	gpk_prefs_update_freq_combo_setup ();
+	gpk_prefs_upgrade_freq_combo_setup ();
+	gpk_prefs_auto_update_combo_setup ();
 
 	/* hide if not supported */
 	if (!pk_bitfield_contain (roles, PK_ROLE_ENUM_GET_DISTRO_UPGRADES)) {
-		widget = glade_xml_get_widget (glade_xml, "label_upgrade");
+		widget = GTK_WIDGET (gtk_builder_get_object (builder, "label_upgrade"));
 		gtk_widget_hide (widget);
-		widget = glade_xml_get_widget (glade_xml, "combobox_upgrade");
+		widget = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_upgrade"));
 		gtk_widget_hide (widget);
 	}
 
 	gtk_widget_show (main_window);
 
+	/* set the parent window if it is specified */
+	if (xid != 0) {
+		egg_debug ("Setting xid %i", xid);
+		gpk_window_set_parent_xid (GTK_WINDOW (main_window), xid);
+	}
+
 	/* wait */
 	gtk_main ();
 
+out_build:
 	g_object_unref (control);
-	g_object_unref (glade_xml);
+	g_object_unref (builder);
 unique_out:
-	g_object_unref (egg_unique);
+	g_object_unref (unique_app);
 
 	return 0;
 }
