@@ -44,7 +44,6 @@
 #include "gpk-gnome.h"
 #include "gpk-dialog.h"
 #include "gpk-error.h"
-#include "gpk-consolekit.h"
 #include "gpk-cell-renderer-size.h"
 #include "gpk-cell-renderer-info.h"
 #include "gpk-cell-renderer-restart.h"
@@ -79,6 +78,7 @@ static PkRestartEnum restart_update = PK_RESTART_ENUM_NONE;
 static guint size_total = 0;
 static GConfClient *gconf_client = NULL;
 static gchar **install_package_ids = NULL;
+static EggConsoleKit *console = NULL;
 
 enum {
 	GPK_UPDATES_COLUMN_TEXT,
@@ -139,18 +139,15 @@ out:
 static void
 gpk_update_viewer_shutdown (void)
 {
-	EggConsoleKit *console;
 	GError *error = NULL;
 	gboolean ret;
 
 	/* use consolekit to restart */
-	console = egg_console_kit_new ();
 	ret = egg_console_kit_restart (console, &error);
 	if (!ret) {
 		egg_warning ("cannot restart: %s", error->message);
 		g_error_free (error);
 	}
-	g_object_unref (console);
 }
 
 /**
@@ -435,7 +432,11 @@ gpk_update_viewer_button_install_cb (GtkWidget *widget, gpointer data)
 	install_package_ids = g_strdupv (package_ids);
 
 	/* get packages that also have to be updated */
+#if PK_CHECK_VERSION(0,5,2)
+	ret = pk_client_simulate_update_packages (client_primary, package_ids, &error);
+#else
 	ret = pk_client_get_depends (client_primary, pk_bitfield_value (PK_FILTER_ENUM_NOT_INSTALLED), package_ids, TRUE, &error);
+#endif
 	if (!ret) {
 		egg_warning ("cannot get depends for updates: %s", error->message);
 		g_error_free (error);
@@ -530,7 +531,7 @@ gpk_update_viewer_details_cb (PkClient *client, const PkDetailsObj *obj, gpointe
 
 	path = gpk_update_viewer_model_get_path (model, obj->id);
 	if (path == NULL) {
-		egg_debug ("not found ID for group");
+		egg_debug ("not found ID for details");
 		return;
 	}
 
@@ -582,7 +583,6 @@ gpk_update_viewer_package_cb (PkClient *client, const PkPackageObj *obj, gpointe
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	GtkTreeViewColumn *column;
-	GtkWidget *widget;
 	GtkTreePath *path;
 	gboolean selected;
 	gboolean scroll;
@@ -595,10 +595,17 @@ gpk_update_viewer_package_cb (PkClient *client, const PkPackageObj *obj, gpointe
 	package_id = pk_package_id_to_string (obj->id);
 
 	/* are we simulating to get deps? */
+#if PK_CHECK_VERSION(0,5,2)
+	if (role == PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES) {
+		egg_debug ("ignoring %s as we are simulating", package_id);
+		goto out;
+	}
+#else
 	if (role == PK_ROLE_ENUM_GET_DEPENDS) {
 		egg_debug ("ignoring %s as we are in the depends phase", package_id);
 		goto out;
 	}
+#endif
 
 	/* used for progress */
 	if (!gpk_update_viewer_is_update_info (obj->info)) {
@@ -641,7 +648,7 @@ gpk_update_viewer_package_cb (PkClient *client, const PkPackageObj *obj, gpointe
 		gtk_tree_path_free (path);
 
 		/* set package description */
-		widget = GTK_WIDGET (gtk_builder_get_object (builder, "label_package"));
+		//widget = GTK_WIDGET (gtk_builder_get_object (builder, "label_package"));
 		//gtk_label_set_label (GTK_LABEL (widget), obj->summary);
 
 		goto out;
@@ -1561,6 +1568,7 @@ gpk_update_viewer_check_restart (PkRestartEnum restart)
 	const gchar *message;
 	const gchar *button;
 	GtkResponseType response;
+	gboolean show_button = TRUE;
 
 	/* get the text */
 	title = gpk_restart_enum_to_localised_text (restart);
@@ -1598,7 +1606,16 @@ gpk_update_viewer_check_restart (PkRestartEnum restart)
 	dialog = gtk_message_dialog_new (window, GTK_DIALOG_MODAL,
 					 GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE,
 					 "%s", title);
-	gtk_dialog_add_button (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
+
+	/* check to see if restart is possible */
+	if (restart == PK_RESTART_ENUM_SYSTEM ||
+	    restart == PK_RESTART_ENUM_SECURITY_SYSTEM) {
+		egg_console_kit_can_restart (console, &show_button, NULL);
+	}
+
+	/* only show the button if we can do the action */
+	if (show_button)
+		gtk_dialog_add_button (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG(dialog), "%s", message);
 	gtk_window_set_icon_name (GTK_WINDOW(dialog), GPK_ICON_SOFTWARE_INSTALLER);
 
@@ -1792,8 +1809,11 @@ gpk_update_viewer_finished_cb (PkClient *client, PkExitEnum exit, guint runtime,
 	}
 
 	/* finished depends check, show any extras */
-	if (role == PK_ROLE_ENUM_GET_DEPENDS) {
-
+#if PK_CHECK_VERSION(0,5,2)
+	if (exit == PK_EXIT_ENUM_SUCCESS && role == PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES) {
+#else
+	if (exit == PK_EXIT_ENUM_SUCCESS && role == PK_ROLE_ENUM_GET_DEPENDS) {
+#endif
 		/* show deps dialog */
 		list = pk_client_get_package_list (client);
 		gpk_helper_deps_update_show (helper_deps_update, list);
@@ -1895,6 +1915,7 @@ gpk_update_viewer_finished_cb (PkClient *client, PkExitEnum exit, guint runtime,
 		    restart_update == PK_RESTART_ENUM_SECURITY_SYSTEM) {
 			gpk_update_viewer_check_restart (restart_update);
 			g_main_loop_quit (loop);
+			goto out;
 		}
 
 		/* hide close button */
@@ -1947,7 +1968,11 @@ gpk_update_viewer_finished_cb (PkClient *client, PkExitEnum exit, guint runtime,
 	/* we pressed cancel */
 	if (exit != PK_EXIT_ENUM_SUCCESS) {
 		gpk_update_viewer_undisable_packages ();
+		widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_install"));
+		gtk_widget_set_sensitive (widget, TRUE);
 	}
+out:
+	return;
 }
 
 static GSList *active_rows = NULL;
@@ -2119,14 +2144,20 @@ gpk_update_viewer_error_code_cb (PkClient *client, PkErrorCodeEnum code, const g
 	/* ignore some errors */
 	if (code == PK_ERROR_ENUM_PROCESS_KILL ||
 	    code == PK_ERROR_ENUM_TRANSACTION_CANCELLED) {
-		egg_debug ("error ignored %s\n%s", pk_error_enum_to_text (code), details);
+		egg_debug ("error ignored %s: %s", pk_error_enum_to_text (code), details);
 		return;
 	}
 
 	/* ignore the ones we can handle */
 	if (code == PK_ERROR_ENUM_NO_LICENSE_AGREEMENT ||
 	    pk_error_code_is_need_untrusted (code)) {
-		egg_debug ("error ignored as we're handling %s\n%s", pk_error_enum_to_text (code), details);
+		egg_debug ("error ignored as we're handling %s: %s", pk_error_enum_to_text (code), details);
+		return;
+	}
+
+	/* ignore not authorised, which seems odd but this will happen if the user clicks cancel */
+	if (code == PK_ERROR_ENUM_NOT_AUTHORIZED) {
+		egg_debug ("auth failure '%s' ignored: %s", pk_error_enum_to_text (code), details);
 		return;
 	}
 
@@ -2233,7 +2264,7 @@ gpk_update_viewer_get_checked_status (gboolean *all_checked, gboolean *none_chec
 	GtkTreeView *treeview;
 	gboolean valid;
 	gboolean update;
-	gboolean clickable;
+	gboolean clickable = FALSE;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 
@@ -2848,6 +2879,7 @@ main (int argc, char *argv[])
 
 	/* get GConf instance */
 	gconf_client = gconf_client_get_default ();
+	console = egg_console_kit_new ();
 
 	g_signal_connect (unique_app, "message-received", G_CALLBACK (gpk_update_viewer_message_received_cb), NULL);
 
@@ -3067,6 +3099,7 @@ out_build:
 	g_object_unref (markdown);
 	g_object_unref (client_primary);
 	g_object_unref (client_secondary);
+	g_object_unref (console);
 	g_object_unref (builder);
 unique_out:
 	g_object_unref (unique_app);
